import { useEffect, useState } from "react"
import { View, Image, ScrollView, Swiper, SwiperItem } from "@tarojs/components"
import CustomNav from "@/components/CustomNav"
import Jianbian from "@/components/Jianbian"
import withLayout from '@/layouts'
import { useModel } from "@/store"
import { getMachineryDetail } from '@/services/machinery'
import micon from '@/assets/machinery/micon2.png'
import './style.less'

export default withLayout((props) => {
  const { router } = props
  const { id } = router.params
  const { location } = useModel('location')
  const [machinery, setMachinery] = useState()
  useEffect(() => {
    getMachineryDetail(id, { location: location, attached: true }).then((res) => {
      setMachinery(res)
    })
  }, [])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='查看详情' />
      </View>
      <View className='index-container'>
        <ScrollView scrollY style={{ height: '100%' }}>
          <Swiper
            circular
            autoplay
            className='swiper'
          >
            {machinery?.imagesList?.map((item, inx) => (
              <SwiperItem key={inx}>
                <Image src={item.url} mode='widthFix' className='storeImage' />
              </SwiperItem>
            ))}
          </Swiper>
          <View className='detailContent'>
            <Jianbian value={machinery?.jobStatus} status={machinery?.status} type='machinery' />
            <View className='detialName'>{machinery?.name}</View>
            <View className='title'>
              <Image src={micon} className='detailIcon' />
              农机详情
              <Image src={micon} className='detailIcon' />
            </View>
            <View>
              {machinery?.contentList?.map(item => {
                return (item.contentType === 'image' ?
                  <Image src={item.content} className='contentImg' /> :
                  <View className='contentText'>{item.content}</View>
                )
              })}
            </View>
          </View>
        </ScrollView>
      </View>
    </View>
  )
})
