import Taro from "@tarojs/taro";
import { Popup } from "@antmjs/vantui";
import { View, Image, Button } from "@tarojs/components"
import CustomNav from "@/components/CustomNav"
import MyCard from "@/components/MyCard"
import withLayout from '@/layouts'
import { useModel } from "@/store";
import { useEffect, useState } from "react"
import { getOrderDetail } from "@/services/order"
import { getJobDetail, toggleJob, overJob } from '@/services/job'
import PositionImg from '@/assets/job/positionImg.png'
import OverPop from '../index/components/OverPop'
import './style.less'


export default withLayout((props) => {
  const { router } = props
  let { id, job } = router.params
  const [value, setValue] = useState()

  const { address } = useModel('location')
  const [show, setShow] = useState(false)
  const [area, setArea] = useState()
  const [showOver, setShowOver] = useState(false)

  const handleWork = () => {
    if (value.status == 0) {
      setShow(true)
    } else {
      setShowOver(true)
    }
  }
  const onClose = () => {
    getJobDetail(id).then(res => {
      setValue(res)
    })
    setShow(false)
  }
  const handleOk = () => {
    toggleJob(value.jobId, { mode: true }).then(() => {
      onClose()
    })
  }
  const onOverClose = () => {
    getJobDetail(id).then(res => {
      setValue(res)
    })
    setShowOver(false)
  }
  const handleOverOk = () => {
    //正整数或两位小数
    if (!isNaN(area)) {
      overJob(value.jobId, { ...value, area: area }).then(res => {
        Taro.showToast({
          title: '恭喜完成作业',
          icon: 'none',
        })
        onOverClose()
      })
    }
    else {
      Taro.showToast({
        title: '请输入正确的面积整数或最多两位小数',
        icon: 'none',
      })
    }
  }
  useEffect(() => {
    if (job) {
      getJobDetail(id).then(res => {
        setValue(res)
      })
    } else {
      getOrderDetail(id).then((res) => {
        setValue(res)
      })
    }
  }, [id, job])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='详情' />
      </View>
      <View className='index-container'>
        {
          job ? <MyCard detail job value={value} onClick={handleWork} /> : <MyCard detail value={value} />
        }
      </View>
      <Popup
        show={show}
        onClose={onClose}
        className='tanchuang'
      >
        <Image src={PositionImg} className='pImg' />
        <View>当前位置在</View>
        <View>{address}</View>
        <Button className='btn' onClick={handleOk}>确认</Button>
      </Popup>

      <OverPop showOver={showOver} onOverClose={onOverClose} area={area} setArea={setArea} handleOverOk={handleOverOk} />

    </View>
  )
})