import Taro from "@tarojs/taro"
import { View, ScrollView } from "@tarojs/components"
import { useEffect, useState } from "react"
import withLayout from '@/layouts'
import CustomNav from "@/components/CustomNav"
import NullCard from "@/components/NullCard";
import WalletCard from "@/components/walletCard"
import ListTitle from "@/components/ListTitle"
import { getAccount, getLogList } from '@/services/account'
import './style.less'


export default withLayout((props) => {
  const [balance, setBlance] = useState(0)
  const [logList, setLogList] = useState([])
  const [currentPage, setCurrentPage] = useState(1)
  const [isMore, setIsMore] = useState(false)
  const goWithdrawal = () => {
    Taro.navigateTo({ url: `/pages/withdrawal/index?balance=${balance}` });
  }

  // 上拉加载
  const handleScrollToLower = () => {
    setCurrentPage(currentPage + 1)
  }
  const getList = () => {
    getAccount().then(res => {
      setBlance(res.amounts / 100)
    })
  }
  useEffect(() => {
    getLogList({ pageNum: currentPage }).then(res => {
      const lst = currentPage === 1 ? res.records || [] : logList.concat(res.records || [])
      //长列表加载当下一页没有数据时
      if (res.records.length == 0 && currentPage != 1) {
        setIsMore(true)
        return
      }
      setLogList(lst)
    })
  }, [currentPage])
  useEffect(() => {
    getList()
  }, [])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='我的钱包' />
      </View>
      <View className='index-container wallet'>
        <ScrollView
          scrollY
          style={{ height: '100%' }}
          onScrollToLower={isMore ? '' : handleScrollToLower}
        >
          <WalletCard onClick={goWithdrawal} value={balance} />
          <ListTitle value='零钱明细' />
          {
            logList.length === 0 ? <NullCard value='暂无明细！' /> :
              logList.map(item => {
                return <View key={item.accountId} className='walletCell'>
                  <View className='flexTop'>
                    <View className='content'>
                      {
                        item.chargeType == 'order_pay' ?
                          '订单收入' :
                          item.chargeType == 'order_refund' ?
                            '用户退款' :
                            item.chargeType == 'withdraw' ?
                              '提现' : ''
                      }
                    </View>
                    <View className={['money', item.chargeType == 'order_pay' ? '' : 'revenue']}>
                      {
                        item.chargeType == 'order_pay' ?
                          '+' + item.money / 100 :
                          '-' + item.money / 100
                      }
                    </View>
                  </View>
                  <View className='withDrawalDetail'>{item.createDate.substr(0, 16)}</View>
                </View>
              })
          }
        </ScrollView>
      </View>
    </View>
  )
})
